###
# #%L
# aiSSEMBLE::Test::MDA::Data Delivery Pyspark
# %%
# Copyright (C) 2021 Booz Allen
# %%
# This software package is licensed under the Booz Allen Public License. All Rights Reserved.
# #L%
###
from abc import ABC
from builtins import bytearray
from .binary_record_field import BinaryRecordField
from typing import Any, Dict
import jsonpickle

class BinaryRecordBase(ABC):
    """
    Base implementation of the Record for BinaryRecord.

    GENERATED CODE - DO NOT MODIFY (add your customizations in BinaryRecord).

    Generated from: templates/data-delivery-data-records/record.base.py.vm
    """

    def __init__(self):
        """
        Default constructor for this record.
        """
        self._binary_field: bytearray = None


    @classmethod
    def from_dict(cls, dict_obj: Dict[str, Any]):
        """
        Creates a record with the given dictionary's data.
        """
        record = cls()
        if dict_obj is not None:
            record.binary_field = dict_obj.get('binaryField')

        return record


    def as_dict(self) -> Dict[str, Any]:
        """
        Returns this record as a dictionary.
        """
        dict_obj = dict()

        dict_obj['binaryField'] = self.binary_field

        return dict_obj


    @classmethod
    def from_json(cls, json_str: str):
        """
        Creates a record with the given json string's data.
        """
        dict_obj = jsonpickle.decode(json_str)
        return cls.from_dict(dict_obj)


    def as_json(self) -> str:
        """
        Returns this record as a json string.
        """
        return jsonpickle.encode(self.as_dict())


    @property
    def binary_field(self) -> bytearray:
        return self._binary_field


    @binary_field.setter
    def binary_field(self, binary_field: bytearray) -> None:
        self._binary_field = binary_field


    def validate(self) -> None:
        """
        Performs the validation for this record.
        """
        pass



    def get_value_by_field(self, field: BinaryRecordField) -> any:
        """
        Returns the value of the given field for this record.
        """
        value = None
        if field == BinaryRecordField.BINARY_FIELD:
            value = self.binary_field

        return value
